aboutsummaryrefslogtreecommitdiff
path: root/src/tool_cfgable.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/tool_cfgable.c')
-rw-r--r--src/tool_cfgable.c5
1 files changed, 3 insertions, 2 deletions
diff --git a/src/tool_cfgable.c b/src/tool_cfgable.c
index bd8707e57..fd62e4b24 100644
--- a/src/tool_cfgable.c
+++ b/src/tool_cfgable.c
@@ -36,8 +36,9 @@ void config_init(struct OperationConfig* config)
config->maxredirs = DEFAULT_MAXREDIRS;
config->proto = CURLPROTO_ALL; /* FIXME: better to read from library */
config->proto_present = FALSE;
- config->proto_redir =
- CURLPROTO_ALL & ~(CURLPROTO_FILE|CURLPROTO_SCP); /* not FILE or SCP */
+ config->proto_redir = CURLPROTO_ALL & /* All except FILE, SCP and SMB */
+ ~(CURLPROTO_FILE | CURLPROTO_SCP | CURLPROTO_SMB |
+ CURLPROTO_SMBS);
config->proto_redir_present = FALSE;
}